@@ -26,6 +26,9 @@ class Frontend(Component):
         log.info("Running create-next-app")
         run(["yarn", "create", "next-app", Projects.FRONTEND])
 
+        log.info("Deleting a poorly formatted index page")
+        open(os.path.join(Projects.FRONTEND, "pages", "index.js"), "w").close()
+
     def delete(self):
         log.warning(f"Deleting the {Projects.FRONTEND} project")
         shutil.rmtree(Projects.FRONTEND)
