@@ -1,3 +1,5 @@
+from importlib_metadata import version
+
 from box import Box
 
 
@@ -17,4 +19,4 @@ project_dir_names = [
 Phases = Box([(t.upper(), t) for t in phase_function_names])
 Projects = Box([(t.upper(), t) for t in project_dir_names])
 
-VENV = "venv"
+__version__ = version("zygoat")
